Scaling Thumbor — Thumbor 6.7.1 documentation

# Scaling Thumbor

- Bernardo Heynemann wrote an article detailing this at Scaling Thumbor;

- Yipit has detailed how they scale thumbor at their engineering blog;

- Square also posted at their engineering blog about how they generate dynamic images with thumbor;

- 99 Designs also has some info on their architecture using thumbor and amazon at their engineering blog.

- heycar also has some info on their architecture using thumbor on with CloudFront and Kubernetes at their engineering blog.